def adasyn_oversampling(
        df, target_col: str, sampling_strategy: str = 'auto', random_state: int = 42, result: str | None = None):
    """
    Applies ADASYN (Adaptive Synthetic Sampling) to address class imbalance in the target variable.

    :param target_col: The name of the target variable column.
    :param sampling_strategy: The sampling strategy to use. This can be 'auto' to automatically balance the dataset.
    :param random_state: The random seed for reproducibility.
    :param result: The name of the new column to store the resampled target variable. If None, a default name is generated.
    """
    from imblearn.over_sampling import ADASYN
    import pandas as pd

    # Separate features and target variable
    X = df.drop(columns=[target_col])
    y = df[target_col]

    ada = ADASYN(sampling_strategy=sampling_strategy, random_state=random_state)
    x_resampled, y_resampled = ada.fit_resample(X, y)

    # Determine result column name
    result_col = result if result else "ADASYN_" + target_col

    # Create DataFrame with resampled target variable
    df_resampled = pd.DataFrame(x_resampled, columns=X.columns)
    df_resampled[result_col] = y_resampled

    return df_resampled


adasyn_oversampling.worker_required = True
