def binarizer(df, numeric_col_list: list[str], threshold=0.0):
    """
    Binarizes the specified feature columns based on a threshold using Binarizer and adds the results as new columns.

    Parameters:
    :param numeric_col_list: List of column names to binarize.
    :param threshold: Threshold value to binarize the features. Should be a float.

    Returns:
    - A DataFrame with new columns added for the binarized features.
    """
    from sklearn.preprocessing import Binarizer

    _binarizer = Binarizer(threshold=float(threshold))

    for col in numeric_col_list:
        # Ensure the column exists in DataFrame
        if col in df.columns:
            # Create a new column name
            new_col_name = f"{col}_binarized"
            # Apply binarization and assign to the new column
            df[new_col_name] = _binarizer.fit_transform(df[[col]])
        else:
            print(f"Warning: Column '{col}' not found in DataFrame. Skipping.")
    return df


binarizer.worker_required = True
