def borderline_smote_oversampling(df, target_col: str, result: list[str] | None = None, random_state: int | None = 42):
    """
    Performs Borderline SMOTE over-sampling on the DataFrame.

    :param target_col: Name of the target column to balance.
    :param result: List to store the resulting column names after over-sampling.
    :param random_state: Seed for random number generation. Defaults to 42.
    """
    import pandas as pd
    from imblearn.over_sampling import BorderlineSMOTE

    # Instantiate BorderlineSMOTE with the specified random_state
    smote = BorderlineSMOTE(random_state=random_state)

    # Extract features and target
    X = df.drop(columns=[target_col])
    y = df[target_col]

    # Apply BorderlineSMOTE
    x_resampled, y_resampled = smote.fit_resample(X, y)

    # Create a new DataFrame with resampled data
    df_resampled = pd.concat(
        [pd.DataFrame(x_resampled, columns=X.columns), pd.DataFrame(y_resampled, columns=[target_col])], axis=1)

    # Add resampled columns to the result list
    if result is not None:
        result.extend(df_resampled.columns.tolist())

    return df_resampled


borderline_smote_oversampling.worker_required = True
