def condensed_nearest_neighbors_undersampling(df, target_col: str, result: list[str] | None, n_neighbors: int = 4):
    """
    Applies Condensed Nearest Neighbors (CNN) under-sampling to balance the dataset by iteratively removing samples that
    can be correctly classified by the existing samples.

    :param target_col: Name of the target column to balance.
    :param result: List to store the resulting column names after under-sampling.
    :param n_neighbors: Number of nearest neighbors to consider. Default is 4.
    """
    import pandas as pd
    from imblearn.under_sampling import CondensedNearestNeighbour

    # Instantiate CondensedNearestNeighbour
    cnn = CondensedNearestNeighbour(n_neighbors=n_neighbors)

    # Extract features and target
    X = df.drop(columns=[target_col])
    y = df[target_col]

    # Apply Condensed Nearest Neighbors (CNN) under-sampling
    x_resampled, y_resampled = cnn.fit_resample(X, y)

    # Create a new DataFrame with resampled data
    df_resampled = pd.concat(
        [pd.DataFrame(x_resampled, columns=X.columns), pd.DataFrame(y_resampled, columns=[target_col])], axis=1)

    # Add resampled columns to the result list
    if result is not None:
        result.extend(df_resampled.columns.tolist())

    return df_resampled


condensed_nearest_neighbors_undersampling.worker_required = True
