def coordinate_finder(df, city_text_col: str | None, api_key: str):
    import requests
    """
    Finds the geographical coordinates (latitude and longitude) for cities listed in a specified column of a DataFrame using the Google Maps Geocoding API.
    
    :param city_text_col: Name of the column containing the city names.
    :param api_key: API key for accessing the Google Maps Geocoding API.
    """
    # the Function to get latitude and logitude of specific city
    def get_lat_lon(city_name, api_key):
        base_url = "https://maps.googleapis.com/maps/api/geocode/json"
        params = {
            "address": city_name,
            "key": api_key
        }
    
        response = requests.get(base_url, params=params)
        if response.status_code == 200:
            data = response.json()
            if data['status'] == 'OK':
                location = data['results'][0]['geometry']['location']
                return (location['lat'], location['lng'])
            else:
                return None
        else:
            raise ValueError("Request failed with status code:", response.status_code)

    
    coordinates = list()

    # for loop to find coordinates of cities
    for city in df[city_text_col].unique():

        lat_lon = get_lat_lon(city, api_key)
        
        if lat_lon is not None:
            coordinates.append((city, lat_lon[0], lat_lon[1]))
        else:
            coordinates.append((city, None, None))

    # Creating DataFrame to merge coordinates to main DataFrame
    coordinates_df = pd.DataFrame(coordinates)
    coordinates_df.rename(columns={0: city_text_col, 1: "Latitude", 2 : "Longitude"}, inplace = True)

    # Merging coordinates to main df
    df = pd.merge(df, coordinates_df, on=city_text_col)
    
    return df

coordinate_finder.worker_required = True
coordinate_finder.supported_engines = ['pandas']