def edited_nearest_neighbours_undersampling(df, target_col: str, result: list[str] | None, n_neighbors: int | None = 4):
    """
    Applies Edited Nearest Neighbours (ENN) under-sampling to balance the dataset by removing the samples whose class label
    differs from the majority class among its k nearest neighbors.

    :param target_col: Name of the target column to balance.
    :param result: List to store the resulting column names after under-sampling.
    :param n_neighbors: Number of nearest neighbors to consider. Default is 4
    """
    import pandas as pd
    from imblearn.under_sampling import EditedNearestNeighbours

    # Check if n_neighbors is None, if so, set it to default value
    if n_neighbors is None:
        n_neighbors = 3

    # Instantiate EditedNearestNeighbours
    enn = EditedNearestNeighbours(n_neighbors=n_neighbors)

    # Extract features and target
    x = df.drop(columns=[target_col])
    y = df[target_col]

    # Apply Edited Nearest Neighbours (ENN) under-sampling
    x_resampled, y_resampled = enn.fit_resample(x, y)

    # Create a new DataFrame with resampled data
    df_resampled = pd.concat(
        [pd.DataFrame(x_resampled, columns=x.columns), pd.DataFrame(y_resampled, columns=[target_col])], axis=1)

    # Add resampled columns to the result list
    if result is not None:
        result.extend(df_resampled.columns.tolist())

    return df_resampled


edited_nearest_neighbours_undersampling.worker_required = True
