def naive_random_oversampling(
        df, target_col: str, sampling_strategy: str = 'auto', random_state: int = 42, result: str | None = None):
    """
    Applies Naive Random Over-sampling to address class imbalance in the target variable.

    :param target_col: The name of the target variable column.
    :param sampling_strategy: The sampling strategy to use. This can be 'auto' to automatically balance the dataset.
    :param random_state: The random seed for reproducibility.
    """
    from imblearn.over_sampling import RandomOverSampler
    import pandas as pd

    # Separate features and target variable
    X = df.drop(columns=[target_col])
    y = df[target_col]

    # Apply Naive Random Over-sampling
    ros = RandomOverSampler(sampling_strategy=sampling_strategy, random_state=random_state)
    x_resampled, y_resampled = ros.fit_resample(X, y)

    # Determine result column name
    result_col = result if result else "RandomOverSampler_" + target_col

    # Create DataFrame with resampled target variable
    df_resampled = pd.DataFrame(x_resampled, columns=X.columns)
    df_resampled[result_col] = y_resampled

    return df_resampled


naive_random_oversampling.worker_required = True
