def one_sided_selection_undersampling(
        df, target_col: str, result: list[str] | None, n_neighbors: int = 4, n_seeds_S: int = 42):
    """
    Applies One Sided Selection (OSS) under-sampling to balance the dataset by removing Tomek links and adding borderline
    samples to the majority class.

    :param target_col: Name of the target column to balance.
    :param result: List to store the resulting column names after under-sampling.
    :param n_neighbors: Number of nearest neighbors to consider. Default is 4.
    :param n_seeds_S: Number of seed samples to use. Default is 42.
    """
    import pandas as pd
    from imblearn.under_sampling import OneSidedSelection

    # Instantiate OneSidedSelection
    oss = OneSidedSelection(n_neighbors=n_neighbors, n_seeds_S=n_seeds_S)

    # Extract features and target
    X = df.drop(columns=[target_col])
    y = df[target_col]

    # Apply One Sided Selection (OSS) under-sampling
    x_resampled, y_resampled = oss.fit_resample(X, y)

    # Create a new DataFrame with resampled data
    df_resampled = pd.concat(
        [pd.DataFrame(x_resampled, columns=X.columns), pd.DataFrame(y_resampled, columns=[target_col])], axis=1)

    # Add resampled columns to the result list
    if result is not None:
        result.extend(df_resampled.columns.tolist())

    return df_resampled


one_sided_selection_undersampling.worker_required = True
