def remove_low_variance_features(df, threshold: float):
    """
    Removes features with low variance from the dataset based on a user-defined threshold.
    Removes non-numeric columns before applying VarianceThreshold.

    :param threshold: Variance threshold for removing features. Features with variance below this threshold will be removed.
    """
    from sklearn.feature_selection import VarianceThreshold
    import pandas as pd

    numeric_df = df.select_dtypes(include=['number'])

    selector = VarianceThreshold(threshold=threshold)
    reduced_data = selector.fit_transform(numeric_df)

    selected_features = numeric_df.columns[selector.get_support(indices=True)]

    reduced_df = pd.DataFrame(reduced_data, columns=selected_features, index=numeric_df.index)

    return reduced_df


remove_low_variance_features.worker_required = True
remove_low_variance_features.supported_engines = ['pandas']
