def repeated_edited_nearest_neighbours_undersampling(
        df, target_col: str, result: list[str] | None = None, n_neighbors: int = 3):
    """
    Applies Repeated Edited Nearest Neighbours (RENN) under-sampling to balance the dataset by iteratively applying the
    Edited Nearest Neighbours (ENN) algorithm.

    :param target_col: Name of the target column to balance.
    :param result: List to store the resulting column names after under-sampling.
    :param n_neighbors: Number of nearest neighbors to consider.
    """
    import pandas as pd
    from imblearn.under_sampling import RepeatedEditedNearestNeighbours

    # Instantiate RepeatedEditedNearestNeighbours
    renn = RepeatedEditedNearestNeighbours(n_neighbors=n_neighbors)

    # Extract features and target
    X = df.drop(columns=[target_col])
    y = df[target_col]

    # Apply Repeated Edited Nearest Neighbours (RENN) under-sampling
    x_resampled, y_resampled = renn.fit_resample(X, y)

    # Create a new DataFrame with resampled data
    df_resampled = pd.concat(
        [pd.DataFrame(x_resampled, columns=X.columns), pd.DataFrame(y_resampled, columns=[target_col])], axis=1)

    # Add resampled columns to the result list
    if result is not None:
        result.extend(df_resampled.columns.tolist())

    return df_resampled


repeated_edited_nearest_neighbours_undersampling.worker_required = True
