def smote_oversampling(df, target_col: str, sampling_strategy: float = 1.0, random_state: int = 42, result: str = None):
    """
    !!! Firstly, you have to install imblearn library with folliwing code: ' !pip install imblearn '
    Applies Synthetic Minority Over-sampling Technique (SMOTE) to address class imbalance in the target variable.

    :param target_col: The name of the target variable column.
    :param sampling_strategy: The sampling strategy to use. This can be a float (if <= 1.0, it corresponds to the desired ratio of the number of samples in the minority class over the number of samples in the majority class after resampling), or a dictionary specifying the number of samples to be generated for each class.
    :param random_state: The random seed for reproducibility.
    :param result: The name of the new column to store the resampled target variable.
    """
    import pandas as pd
    from imblearn.over_sampling import SMOTE

    # Separate features and target variable
    x = df.drop(columns=[target_col])
    y = df[target_col]

    # Apply SMOTE
    smote = SMOTE(sampling_strategy=sampling_strategy, random_state=random_state)
    x_resampled, y_resampled = smote.fit_resample(x, y)

    # Create DataFrame with resampled target variable
    df_resampled = pd.DataFrame(x_resampled, columns=x.columns)
    df_resampled[target_col] = y_resampled

    # If result is provided, rename the target column
    if result:
        df_resampled.rename(columns={target_col: result}, inplace=True)

    return df_resampled


smote_oversampling.worker_required = True
