def tomek_links_undersampling(df, target_col: str, result: list[str] | None):
    """
    Applies Tomek Links under-sampling to balance the dataset by removing Tomek links, i.e., pairs of instances that are
    nearest neighbors and of opposite classes.

    :param target_col: Name of the target column to balance.
    :param result: List to store the resulting column names after under-sampling.
    """
    import pandas as pd
    from imblearn.under_sampling import TomekLinks

    # Instantiate TomekLinks
    tl = TomekLinks()

    # Extract features and target
    X = df.drop(columns=[target_col])
    y = df[target_col]

    # Apply Tomek Links under-sampling
    x_resampled, y_resampled = tl.fit_resample(X, y)

    # Create a new DataFrame with resampled data
    df_resampled = pd.concat(
        [pd.DataFrame(x_resampled, columns=X.columns), pd.DataFrame(y_resampled, columns=[target_col])], axis=1)

    # Add resampled columns to the result list
    if result is not None:
        result.extend(df_resampled.columns.tolist())

    return df_resampled


tomek_links_undersampling.worker_required = True
